<h1>Reload and use a model</h1>
<div class="photon-docu-header">
    <p>
        Every successful trained pipeline saves the best model in the result folder as best_model.photonai. 
        To collaborate with other people share your trained model saved in this file. Have a look at the following 
        example script if you want to reload the trained <a href="../../api/base/hyperpipe">Hyperpipe</a>:
    </p>
</div>

``` python
{% include "examples/basic/save_load.py" %} 

```